@@ -109,8 +109,11 @@ convert_ratio_to_df <- function(table, domains) {
 
 #--------------------------------------------------------------
 
+
 get_unweighted <- function(table, disenio, var, domains) {
 
+  domains <- create_groupby_vars(domains)
+
   if (!is.null(domains)) {
     unweighted_cases <- get_sample_size(disenio$variables, c(domains, var) ) %>%
       dplyr::mutate_at(dplyr::vars(domains), as.character)  %>%
@@ -136,6 +139,8 @@ get_unweighted <- function(table, disenio, var, domains) {
 
 }
 
+
+
 #-----------------------------------------------------------------------
 
 get_log_cv <- function(data) {
@@ -267,7 +272,6 @@ create_output <- function(table, domains, gl, n, cv, env = parent.frame()) {
                        by = domains) %>%
       dplyr::left_join(cv %>% dplyr::select(c(domains, "cv")),
                        by = domains)
-
   } else {
 
     var <- get("var",envir = env)
@@ -298,12 +302,19 @@ create_output <- function(table, domains, gl, n, cv, env = parent.frame()) {
 #' @param table \code{dataframe} with results
 #' @param design design
 #' @param domains \code{vector} with domains
+#' @param type_est type of estimation: all or size.
+#' @param env parent environment
 #' @import haven
 #' @return \code{dataframe} with results including including CV
 
-get_cv <- function(table, design, domains) {
+get_cv <- function(table, design, domains, type_est = "all", env = parent.frame()) {
 
-  if (!is.null(domains)) {
+  # weird case: national estimations for ine df-approach. In this case there is one element inside domains, but that is
+  # because the strategy used before this function
+  if (length(domains) == 1 && type_est == "size" && get("df_type", env) == "ine") {
+    cv <- cv(table, design = design)
+
+  } else if (!is.null(domains)) { # it considers domains
     cv <- cv(table, design = design)
 
     cv <- table %>%
@@ -311,10 +322,12 @@ get_cv <- function(table, design, domains) {
       dplyr::bind_cols(cv = cv) %>%
       dplyr::mutate_at(.vars = dplyr::vars(domains), .funs = as.character)
 
-  } else {
+  } else { # national level for all kind of estimations
     cv <- cv(table, design = design)
   }
 
+
+
   return(cv)
 }
 
@@ -326,11 +339,11 @@ get_cv <- function(table, design, domains) {
 #' Receive data and domains. Returns a data frame with the psu, strata and df for each cell
 #' @param data \code{dataframe}
 #' @param domains \code{string} with domains
-#' @param df_type \code{string} Use degrees of freedom calculation approach from INE Chile or CEPAL, by default "ine".
+#' @param df_type \code{string} Use degrees of freedom calculation approach from INE Chile or eclac, by default "ine".
 #' @return \code{dataframe} with results including degrees of freedom
 
 
-get_df <- function(data, domains,df_type = "cepal"){
+get_df <- function(data, domains, df_type = "eclac"){
   design <- data
   data <- data$variables
 
@@ -362,7 +375,7 @@ get_df <- function(data, domains,df_type = "cepal"){
         dplyr::ungroup()   %>%
         dplyr::select(-c("upm","varstrat"))
 
-    } else if(df_type == "cepal"){
+    } else if(df_type == "eclac"){
       gl <- calcular_upm(design$variables, domains) %>%
         dplyr::left_join(calcular_estrato(design$variables, domains), by = domains) %>%
         dplyr::mutate(df = .data$upm - .data$varstrat)  %>%
@@ -387,7 +400,7 @@ get_df <- function(data, domains,df_type = "cepal"){
 
   #  print(paste("fe",gl))
 
-    } else if(df_type == "cepal"){
+    } else if(df_type == "eclac"){
        # varstrat <- length(unique(design$variables$varstrat))
        # varunit <- length(unique(design$variables$varunit))
        # gl <- varunit - varstrat
@@ -543,10 +556,12 @@ unificar_variables_factExp = function(disenio){
 #' @param env \code{environment} parent frame
 #' @param fun function required regarding the estimation
 #' @param denom denominator. This parameter works for the ratio estimation
+#' @param env parent environment
+#' @param type_est type of estimation: all or size
 #' @return \code{dataframe} containing  main results from survey
 #' @import survey
 
-get_survey_table <-  function(var, domains, complex_design, estimation = "mean", env = parent.frame(), fun, denom = NULL) {
+get_survey_table <-  function(var, domains, complex_design, estimation = "mean", env = parent.frame(), fun, denom = NULL, type_est = "all") {
 
 
   # El primer if es para domains
@@ -554,12 +569,25 @@ get_survey_table <-  function(var, domains, complex_design, estimation = "mean",
 
     if (estimation == "mean") { # para estimaciones de media, proporción y tamaños
 
-      estimacion <-  survey::svyby(formula = var,
+      estimacion <-  survey::svyby(formula =  var,
                                    by = domains,
                                    design = complex_design,
                                    FUN = fun,
                                    deff = get("deff", env))
-      # sometimes survey outputs two coluns with the same name. In those cases we keep the first occurrence and the second one is modified
+
+
+      # This is a patch because a problem with df_type = INE. We needed to add the var to domains in order to get the DF and sample size according to
+      # INE approach. This decision  produces an error in the deff calculation. So we implement here a specific procedure for the size function. The idea is
+      # to avoid any modification in the rest of the code.
+      if (type_est == "size" &&  get("df_type", env) == "ine" ) {
+
+        names(estimacion)[names(estimacion) == formula_to_string(var) ] <- "est"
+        estimacion[formula_to_string(var)] <- 1
+
+      }
+
+
+      # sometimes survey outputs two columns with the same name. In those cases we keep the first occurrence and the second one is modified
       estimacion <- fix_repeated_columns(estimacion, v = var)
 
       # drop rows with zero values
@@ -619,11 +647,11 @@ get_survey_table <-  function(var, domains, complex_design, estimation = "mean",
 #-----------------------------------------------------------------------
 
 
-calcular_tabla_ratio <-  function(var,denominador, domains = NULL, complex_design, env = parent.frame()) {
+calcular_tabla_ratio <-  function(var,denominator, domains = NULL, complex_design, env = parent.frame()) {
   if (!is.null(domains)) {
-    estimacion <- survey::svyby(var, denominator = denominador,design =  complex_design, by = domains , FUN = svyratio, deff = get("deff", env))
+    estimacion <- survey::svyby(var, denominator = denominator,design =  complex_design, by = domains , FUN = svyratio, deff = get("deff", env))
   } else {
-    estimacion <- survey::svyratio(var, denominator = denominador, design = complex_design, deff = get("deff", env))
+    estimacion <- survey::svyratio(var, denominator = denominator, design = complex_design, deff = get("deff", env))
   }
   return(estimacion)
 }
@@ -633,7 +661,7 @@ calcular_tabla_ratio <-  function(var,denominador, domains = NULL, complex_desig
 
 
 
-get_sample_size <- function(data, domains = NULL, df_type = "cepal", env = parent.frame()) {
+get_sample_size <- function(data, domains = NULL, df_type = "eclac", env = parent.frame()) {
 
   if(df_type == "ine"){
 
@@ -646,7 +674,7 @@ get_sample_size <- function(data, domains = NULL, df_type = "cepal", env = paren
       dplyr::filter(!!rlang::parse_expr(estimation_var) == 1) %>%
       dplyr::mutate_at(domains, as.character)
 
-  }else if(df_type == "cepal"){
+  }else if(df_type == "eclac"){
 
     data %>%
       dplyr::group_by_at(.vars = domains) %>%
@@ -858,7 +886,7 @@ get_ess <- function(ess, env = parent.frame() ) {
 #' internal function to calculate ratios estimations
 #'
 #' @param var numeric variable within the \code{dataframe}, is the numerator of the ratio to be calculated.
-#' @param denominador numeric variable within the \code{dataframe}, is the denominator of the ratio to be calculated.
+#' @param denominator numeric variable within the \code{dataframe}, is the denominator of the ratio to be calculated.
 #' @param domains domains to be estimated separated by the + character.
 #' @param disenio complex design created by \code{survey} package
 #' @param subpop integer dummy variable to filter the dataframe
@@ -875,7 +903,7 @@ get_ess <- function(ess, env = parent.frame() ) {
 #' @return \code{dataframe} that contains the inputs and all domains to be evaluated
 #'
 
-create_ratio_internal <- function(var,denominador, domains = NULL, subpop = NULL, disenio, ci = FALSE, deff = FALSE, ess = FALSE,
+create_ratio_internal <- function(var,denominator, domains = NULL, subpop = NULL, disenio, ci = FALSE, deff = FALSE, ess = FALSE,
                                   ajuste_ene = FALSE, unweighted = FALSE, rel_error = FALSE, rm.na = FALSE) {
 
   # get design variables
@@ -885,7 +913,7 @@ create_ratio_internal <- function(var,denominador, domains = NULL, subpop = NULL
   agrupacion <- create_groupby_vars(domains)
 
   # Select relevant columns
-  disenio <- disenio[ ,  c(agrupacion, var, subpop, design_vars, denominador)]
+  disenio <- disenio[ ,  c(agrupacion, var, subpop, design_vars, denominator)]
 
   # Chequear que la variable objetivo y la variable subpop cumplan con ciertas condiciones
   check_input_var(var, disenio, estimation = "ratio")
@@ -899,12 +927,12 @@ create_ratio_internal <- function(var,denominador, domains = NULL, subpop = NULL
 
   # Convertir everything tolower to avoid problems
   names(disenio$variables) <- tolower(names(disenio$variables))
-  lower_params <- purrr::map(list("var" = var, "subpop" = subpop, "domains" = domains, "denominador" = denominador ), tolower_strings)
+  lower_params <- purrr::map(list("var" = var, "subpop" = subpop, "domains" = domains, "denominator" = denominator ), tolower_strings)
 
   var <- lower_params$var
   subpop <- lower_params$subpop
   domains <- lower_params$domains
-  denominador <- lower_params$denominador
+  denominator <- lower_params$denominator
 
   # Sacar los NA si el usuario lo requiere
   if (rm.na == TRUE) {
@@ -917,9 +945,9 @@ create_ratio_internal <- function(var,denominador, domains = NULL, subpop = NULL
   #Convertir los inputs en formulas para adecuarlos a survey
   var_form <- convert_to_formula(var)
   domains_form <- convert_to_formula(domains)
-  denominador_form <- convert_to_formula(denominador)
+  denominator_form <- convert_to_formula(denominator)
 
-  tabla <- get_survey_table(var_form, domains_form, disenio, fun = survey::svyratio, estimation = "ratio", denom = denominador_form)
+  tabla <- get_survey_table(var_form, domains_form, disenio, fun = survey::svyratio, estimation = "ratio", denom = denominator_form)
 
   # Crear listado de variables que se usan para el cálculo
   agrupacion <- create_groupby_vars(domains)
@@ -943,7 +971,7 @@ create_ratio_internal <- function(var,denominador, domains = NULL, subpop = NULL
   final <- create_output(tabla, agrupacion,  gl, n, cv)
 
   # Ordenar las columnas y estandarizar los nombres de las variables
-  final <- standardize_columns(final, var, denominador )
+  final <- standardize_columns(final, var, denominator )
 
 
 
@@ -1056,7 +1084,7 @@ create_prop_internal <- function(var, domains = NULL, subpop = NULL, disenio, ci
   final <- create_output(tabla, agrupacion,  gl, n, cv)
 
   # Ordenar las columnas y estandarizar los nombres de las variables
-  final <- standardize_columns(final, var, denom = get("denominador", env) )
+  final <- standardize_columns(final, var, denom = get("denominator", env) )
 
 
   # Add unweighted counting
